Smith 2009 Atlas


Notes
-----
This atlas provides spatial maps of the major brain networks during task-constrained brain activity and task-unconstrained (resting) brain activity.

Those were derived from 6 minutes of resting-state time series from 36 subjects as well as from the from the smoothed task activity coordinates of healthy subjects stored in the BrainMap database.

Content
-------
    :'rsn20': 20 ICA maps derived from resting-state decomposition
    :'rsn10': 10 ICA maps from the above that matched across task and rest
    :'rsn70': 70 ICA maps derived from resting-state decomposition
    :'bm20': 20 ICA maps derived from decomposition BrainMap task data
    :'bm10': 10 ICA maps from the above that matched across task and rest
    :'bm70': 70 ICA maps derived from decomposition BrainMap task data


References
----------

For more information about this dataset's structure:
http://www.fmrib.ox.ac.uk/analysis/brainmap+rsns/

S.M. Smith, P.T. Fox, K.L. Miller, D.C. Glahn, P.M. Fox, C.E. Mackay, N.
Filippini, K.E. Watkins, R. Toro, A.R. Laird, and C.F. Beckmann.
Correspondence of the brain's functional architecture during activation and
rest. Proc Natl Acad Sci USA (PNAS), 106(31):13040-13045, 2009.

A.R. Laird, P.M. Fox, S.B. Eickhoff, J.A. Turner, K.L. Ray, D.R. McKay, D.C
Glahn, C.F. Beckmann, S.M. Smith, and P.T. Fox. Behavioral interpretations
of intrinsic connectivity networks. Journal of Cognitive Neuroscience, 2011

Licence: unknown.